@@ -266,7 +266,7 @@ parse_conf_file (int *argc, char ***argv) {
   size_t idx;
 
   /* assumes program name is on argv[0], though, it is not guaranteed */
-  append_to_argv (&nargc, &nargv, xstrdup (*argv[0] ?: PACKAGE_NAME));
+  append_to_argv (&nargc, &nargv, xstrdup (*argv[0] ? : PACKAGE_NAME));
 
   /* determine which config file to open, default or custom */
   path = get_config_file_path ();
@@ -629,8 +629,10 @@ set_spec_date_time_num_format (void) {
     return;
   }
 
-  if (conf.date_spec_hr && strchr (tf, 'H'))
+  if (conf.date_spec_hr == 1 && strchr (tf, 'H'))
     buf = append_spec_date_format (df, "%H");
+  else if (conf.date_spec_hr == 2 && strchr (tf, 'M'))
+    buf = append_spec_date_format (df, "%H%M");
   else
     buf = xstrdup (df);
 
@@ -661,6 +663,8 @@ set_spec_date_time_format (void) {
     buflen += snprintf (buf + buflen, flen - buflen, "%%Y");
   if (strchr (fmt, 'H'))
     buflen += snprintf (buf + buflen, flen - buflen, ":%%H");
+  if (strchr (fmt, 'M'))
+    buflen += snprintf (buf + buflen, flen - buflen, ":%%M");
 
   conf.spec_date_time_format = buf;
 }
